==> react-tcf-second-layer-1.6.0.tgz: package/lib/components/tcf-secondLayer-decision-group/index.js <==
import React from 'react';
import SuiButton from '@s-ui/react-atom-button';
import TcfSecondLayerUserDecision from '../tcf-secondLayer-user-decision';
export default function TcfSecondLayerDecisionGroup(_ref) {
  var _descriptionKeys;

  var name = _ref.name,
      i18n = _ref.i18n,
      baseClass = _ref.baseClass,
      descriptions = _ref.descriptions,
      state = _ref.state,
      filteredIds = _ref.filteredIds,
      hasConsent = _ref.hasConsent,
      _onConsentChange = _ref.onConsentChange,
      onAcceptAll = _ref.onAcceptAll,
      onRejectAll = _ref.onRejectAll,
      vendorList = _ref.vendorList,
      expandedContent = _ref.expandedContent;
  var descriptionKeys = descriptions && Object.keys(descriptions).map(function (key) {
    return parseInt(key);
  });

  if (filteredIds) {
    descriptionKeys = descriptionKeys.filter(function (key) {
      return filteredIds.includes(key);
    });
  }

  if (!((_descriptionKeys = descriptionKeys) == null ? void 0 : _descriptionKeys.length)) {
    return null;
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-title-container"
  }, /*#__PURE__*/React.createElement("h2", {
    className: baseClass + "-title"
  }, name), hasConsent ? /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-buttons"
  }, /*#__PURE__*/React.createElement(SuiButton, {
    size: "small",
    design: "outline",
    onClick: onRejectAll
  }, i18n.DISABLE_BUTTON), /*#__PURE__*/React.createElement(SuiButton, {
    size: "small",
    onClick: onAcceptAll
  }, i18n.ENABLE_BUTTON)) : null), descriptionKeys.map(function (key, index) {
    var consentValue = (state == null ? void 0 : state.consents) ? state.consents[key] : state == null ? void 0 : state[key];
    return /*#__PURE__*/React.createElement(TcfSecondLayerUserDecision, {
      key: key + "-" + index,
      baseClass: baseClass + "-item",
      info: descriptions[key],
      consentValue: consentValue,
      hasConsent: hasConsent,
      i18n: i18n,
      vendorList: vendorList,
      onConsentChange: function onConsentChange(value) {
        return _onConsentChange({
          index: key,
          value: value
        });
      },
      expandedContent: expandedContent
    });
  }));
}

==> react-tcf-second-layer-1.9.0.tgz: package/lib/components/tcf-secondLayer-decision-group/index.js <==
import React from 'react';
import SuiButton from '@s-ui/react-atom-button';
import TcfSecondLayerUserDecision from '../tcf-secondLayer-user-decision';
import TcfSecondLayerVendorsUserDecision from '../tcf-secondLayer-vendors-user-decision';
export default function TcfSecondLayerDecisionGroup(_ref) {
  var _descriptionKeys;

  var name = _ref.name,
      i18n = _ref.i18n,
      baseClass = _ref.baseClass,
      descriptions = _ref.descriptions,
      state = _ref.state,
      filteredIds = _ref.filteredIds,
      hasConsent = _ref.hasConsent,
      _onConsentChange = _ref.onConsentChange,
      onAcceptAll = _ref.onAcceptAll,
      onRejectAll = _ref.onRejectAll,
      vendorList = _ref.vendorList,
      expandedContent = _ref.expandedContent,
      isVendorLayer = _ref.isVendorLayer;
  var descriptionKeys = descriptions && Object.keys(descriptions).map(function (key) {
    return parseInt(key);
  });

  if (filteredIds) {
    descriptionKeys = descriptionKeys.filter(function (key) {
      return filteredIds.includes(key);
    });
  }

  if (!((_descriptionKeys = descriptionKeys) == null ? void 0 : _descriptionKeys.length)) {
    return null;
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-title-container"
  }, /*#__PURE__*/React.createElement("h2", {
    className: baseClass + "-title"
  }, name), hasConsent ? /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-buttons"
  }, /*#__PURE__*/React.createElement(SuiButton, {
    size: "small",
    design: "outline",
    onClick: onRejectAll
  }, i18n.DISABLE_BUTTON), /*#__PURE__*/React.createElement(SuiButton, {
    size: "small",
    onClick: onAcceptAll
  }, i18n.ENABLE_BUTTON)) : null), descriptionKeys.map(function (key, index) {
    var consentValue = (state == null ? void 0 : state.consents) ? state.consents[key] : state == null ? void 0 : state[key];
    return isVendorLayer ? /*#__PURE__*/React.createElement(TcfSecondLayerUserDecision, {
      key: key + "-" + index,
      baseClass: baseClass + "-item",
      info: descriptions[key],
      consentValue: consentValue,
      hasConsent: hasConsent,
      i18n: i18n,
      vendorList: vendorList,
      onConsentChange: function onConsentChange(value) {
        return _onConsentChange({
          index: key,
          value: value
        });
      },
      expandedContent: expandedContent
    }) : /*#__PURE__*/React.createElement(TcfSecondLayerVendorsUserDecision, {
      key: key + "-" + index,
      baseClass: baseClass + "-item--vendors",
      info: descriptions[key],
      consentValue: consentValue,
      hasConsent: hasConsent,
      i18n: i18n,
      vendorList: vendorList,
      onConsentChange: function onConsentChange(value) {
        return _onConsentChange({
          index: key,
          value: value
        });
      },
      expandedContent: expandedContent
    });
  }));
}
